# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from azdata.cli.commands.app.constants import (RUNTIMES, TEMPLATE_DISPLAY_URL)
from azdata.cli.commands.app.spec import Spec
from azdata.cli.commands.app.validators import (validate_io, validate_inputs)
from azdata.cli.core.configuration import Configuration
from knack.arguments import ArgumentsContext


def load_arguments(self, command):
    """Load specialized arguments for commands"""
    from azdata.cli.commands.app import _

    # ----------------------------------------------------------------------
    # -- [app] --
    # ----------------------------------------------------------------------

    with ArgumentsContext(self, 'app template list') as arg_context:
        arg_context.argument(
            'url',
            options_list=['--url', '-u'],
            help=_('Specify a different template repository location. '
                   'Default: {}').format(TEMPLATE_DISPLAY_URL)
        )

    with ArgumentsContext(self, 'app template pull') as arg_context:
        arg_context.argument(
            'url',
            options_list=['--url', '-u'],
            help=_('Specify a different template repository location. '
                   'Default: {}').format(TEMPLATE_DISPLAY_URL)
        )

        arg_context.argument(
            'name',
            options_list=['--name', '-n'],
            help=_('Template name. For a full list off supported template names'
                   'run `{} app template list`').format(Configuration().
                                                        CLI_NAME)
        )

        arg_context.argument(
            'destination',
            options_list=['--destination', '-d'],
            help=_('Where to place the application skeleton template.')
        )

    with ArgumentsContext(self, 'app init') as arg_context:
        arg_context.argument(
            'spec',
            options_list=['--spec', '-s'],
            action='store_true',
            help=_('Generate just an application {}.').format(Spec.FILE)
        )

        arg_context.argument(
            'name',
            options_list=['--name', '-n'],
            help=_('Application name.')
        )

        arg_context.argument(
            'version',
            options_list=['--version', '-v'],
            help=_('Application version.')
        )

        arg_context.argument(
            'template',
            options_list=['--template', '-t'],
            help=_('Template name. For a full list off supported template '
                   'names run `{} app template list`').format(Configuration().
                                                              CLI_NAME)
        )

        arg_context.argument(
            'url',
            options_list=['--url', '-u'],
            help=_('Specify a different template repository location. Default: '
                   '{}').format(TEMPLATE_DISPLAY_URL)
        )

        arg_context.argument(
            'destination',
            options_list=['--destination', '-d'],
            help=_('Where to place the application skeleton. Default: current '
                   'working directory.')
        )

    with ArgumentsContext(self, 'app create') as arg_context:
        arg_context.argument(
            'spec',
            options_list=['--spec', '-s'],
            help=_('Path to a directory with a YAML spec file describing the '
                   'application.')
        )

    with ArgumentsContext(self, 'app update') as arg_context:
        arg_context.argument(
            'spec',
            options_list=['--spec', '-s'],
            help=_('Path to a directory with a YAML spec file describing the '
                   'application.')
        )

        arg_context.argument(
            'yes',
            options_list=['--yes', '-y'],
            action='store_true',
            help=_('Do not prompt for confirmation when updating an '
                   'application from the CWD\'s spec.yaml file.')
        )

    with ArgumentsContext(self, 'app run') as arg_context:
        arg_context.argument(
            'name',
            options_list=['--name', '-n'],
            help=_('Application name.')
        )

        arg_context.argument(
            'version',
            options_list=['--version', '-v'],
            help=_('Application version.')
        )

        arg_context.argument(
            'inputs',
            options_list=['--inputs'],
            validator=validate_inputs,
            help=_('Application input parameters in a CSV `name=value` format.')
        )

    with ArgumentsContext(self, 'app delete') as arg_context:
        arg_context.argument(
            'name',
            options_list=['--name', '-n'],
            help=_('Application name.')
        )

        arg_context.argument(
            'version',
            options_list=['--version', '-v'],
            help=_('Application version.')
        )

    with ArgumentsContext(self, 'app list') as arg_context:
        arg_context.argument(
            'name',
            options_list=['--name', '-n'],
            help='Application name.'
        )

        arg_context.argument(
            'version',
            options_list=['--version', '-v'],
            help=_('Application version.')
        )

    with ArgumentsContext(self, 'app describe') as arg_context:
        arg_context.argument(
            'name',
            options_list=['--name', '-n'],
            help=_('Application name.')
        )

        arg_context.argument(
            'version',
            options_list=['--version', '-v'],
            help=_('Application version.')
        )

        arg_context.argument(
            'spec',
            options_list=['--spec', '-s'],
            help=_('Path to a directory with a YAML spec file describing the '
                   'application.')
        )
