# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

import os

ARC_NAME = 'arc'
"""
Command group constant
"""

DATA_CONTROLLER_CUSTOM_RESOURCE = 'datacontroller'
"""
Name of control plane custom resource
"""

CONTROLLER_LABEL = 'controller'
"""
Name of the controller app label
"""

CONTROLLER_SVC = 'controller-svc-external'
"""
Name of external controller service
"""

MGMT_PROXY = 'mgmtproxy-svc-external'
"""
Name of management proxy service
"""

BASE = os.path.dirname(os.path.realpath(__file__))
"""
Base directory
"""

CONFIG_DIR = os.path.join(BASE, 'deployment-configs')
"""
Config directory
"""

TEMPLATE_DIR = os.path.join(BASE, 'templates')
"""
Custom resource definition directory
"""

DATA_CONTROLLER_CRD = os.path.join(TEMPLATE_DIR, 'data_controller_crd.yaml')
"""
File location for control plane CRD.
"""

POSTGRES_11_CRD = os.path.join(TEMPLATE_DIR, 'postgres_11_crd.yaml')
"""
File location for postgres 11 CRD.
"""

POSTGRES_12_CRD = os.path.join(TEMPLATE_DIR, 'postgres_12_crd.yaml')
"""
File location for postgres 12 CRD.
"""

SQLMI_CRD = os.path.join(TEMPLATE_DIR, 'sqlmi_crd.yaml')
"""
File location for sqlmi CRD.
"""

HELP_DIR = os.path.join(CONFIG_DIR, 'help')
"""
Help config directory
"""

CONTROL_CONFIG_FILENAME = 'control.json'
"""
Control config file name
"""

CONFIG_FILES = [CONTROL_CONFIG_FILENAME]
"""
Array of config file names from profiles
"""

############################################################################
# Data Controller constants
############################################################################

GUID_REGEX = r'[0-9a-f]{8}\-([0-9a-f]{4}\-){3}[0-9a-f]{12}'
"""
Used to validate subscription IDs
"""

DIRECT="direct"
"""
Direct connection mode
"""

INDIRECT="indirect"
"""
Indirect connection mode
"""

CONNECTIVITY_TYPES = [DIRECT, INDIRECT]
"""
Supported connectivity types for data controller
"""

SUPPORTED_REGIONS = ['eastus', 'eastus2', 'centralus', 'westeurope', 'southeastasia', 'westus2', 'japaneast', 'australiaeast', 'koreacentral', 'northeurope', 'uksouth', 'francecentral']
"""
Supported Azure regions for data controller. This list does not include EUAP regions.
"""

SUPPORTED_EUAP_REGIONS = ['eastus2euap', 'centraluseuap', 'eastasia']
"""
Supported Azure EUAP regions for data controller.
"""
