# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------


def load_arguments(self, _):
    from knack.arguments import ArgumentsContext
    from azdata.cli.commands.notebook import _

    with ArgumentsContext(self, 'notebook view') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            default="/",
            help=_('The path to the notebook to view.')
        )

        arg_context.argument(
            'continue_on_error',
            options_list=['--continue-on-error', '-c'],
            action='store_true',
            help=_('Continue displaying additional cells ignoring any cell errors found in the notebook output.  The default behavior is to stop on error.  Stopping makes seeing the first cell that encountered an error easier.')
        )

    with ArgumentsContext(self, 'notebook run') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            default="/",
            help=_('The file path to the notebook to run.')
        )

        arg_context.argument(
            'output_path',
            options_list=['--output-path'],
            required=False,
            help=_('Directory path to use for notebook output.  Notebook with output data and any notebook generated files are generated relative to this directory.')
        )

        arg_context.argument(
            'output_html',
            options_list=['--output-html'],
            action='store_true',
            help=_('Optional flag indicatingg whether to additionally convert the output notebook to HTML format.  Creates a second output file.')
        )

        arg_context.argument(
            'arguments',
            options_list=['--arguments', '-a'],
            required=False,
            help=_('Optional list of notebook arguments to inject into the notebook execution.  Encoded as a JSON dictionary.  Example: \'{"name":"value", "name2":"value2"}\'')
        )

        arg_context.argument(
            'timeout',
            options_list=['--timeout', '-t'],
            default="600",
            type=int,
            help=_('Seconds to wait for the execution to complete. The value -1 indicates wait forever.')
        )

        arg_context.argument(
            'interactive',
            options_list=['--interactive', '-i'],
            action='store_true',
            help=_('Run a notebook in an interactive mode.')
        )

        arg_context.argument(
            'clear',
            options_list=['--clear', '-c'],
            action='store_true',
            help=_('In interactive mode clear the console before rendering a cell.')
        )


