# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from azdata.cli.core.models.dict_utils import SerializationUtils
from azdata.cli.core.constants import (MAX_PORT_NUBMER, MIN_PORT_NUMBER, PORT_REQUIREMENTS)


class EndpointSpec(SerializationUtils):
    """
    A copy of the backend Endpoint class as used in the DataControllerCustomResource spec
    """
    def __init__(self, name: str = None, serviceType: str = None, port: int = None):
        # Since `None` throws an error for port number we're allowing only the constructor to initialize to None here.
        # This would be an error in deserialization/argument application steps
        if port:
            self.port = port
        else:
            self._port = None

        if name:
            self.name = name

        if serviceType:
            self._serviceType = serviceType

    @property
    def name(self) -> str:
        return self._name

    @name.setter
    def name(self, n: str):
        self._name = n

    @property
    def dnsName(self) -> str:
        return self._dnsName

    @dnsName.setter
    def dnsName(self, n: str):
        self._dnsName = n

    @property
    def serviceType(self) -> str:
        return self._serviceType

    @serviceType.setter
    def serviceType(self, t: str):
        self._serviceType = t

    @property
    def port(self) -> str:
        return self._port

    @port.setter
    def port(self, p: str):
        try:
            val = int(p)
            if not MIN_PORT_NUMBER <= val <= MAX_PORT_NUBMER:
                raise ValueError(PORT_REQUIREMENTS)
        except ValueError:
            raise ValueError(PORT_REQUIREMENTS)
        except TypeError:
            raise ValueError(PORT_REQUIREMENTS)

        self._port = p

    def _to_dict(self):
        """
        @override
        """
        return {
            "port": getattr(self, "port", None),
            "serviceType": getattr(self, "serviceType", None),
            "name": getattr(self, "name", None),
            "dnsName": getattr(self, "dnsName", None)
        }

    def _hydrate(self, d: dict):
        """
        @override
        """
        if "port" in d:
            self.port = d["port"]

        if "serviceType" in d:
            self.serviceType = d["serviceType"]

        if "name" in d:
            self.name = d["name"]

        if "dnsName" in d:
            self.dnsName = d["dnsName"]
