# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from azdata.cli.core.models.dict_utils import SerializationUtils
from azdata.cli.core.constants import (MAX_PORT_NUBMER, MIN_PORT_NUMBER, PORT_REQUIREMENTS)


class ServiceSpec(SerializationUtils):
    """
    An internal representation of the service spec for a custom resource
    """
    def __init__(self, serviceType: str = None, port: int = None):
        if port:
            self.port = port
        else:
            self._port = None

        if serviceType:
            self.serviceType = serviceType

    @property
    def serviceType(self) -> str:
        return self._serviceType

    @serviceType.setter
    def serviceType(self, t: str):
        self._serviceType = t

    @property
    def port(self) -> str:
        return self._port

    @port.setter
    def port(self, p: str):
        try:
            val = int(p)
            if not MIN_PORT_NUMBER <= val <= MAX_PORT_NUBMER:
                raise ValueError(PORT_REQUIREMENTS)
        except ValueError:
            raise ValueError(PORT_REQUIREMENTS)
        except TypeError:
            raise ValueError(PORT_REQUIREMENTS)

        self._port = val

    def _to_dict(self):
        """
        @override
        """
        return {
            "port": getattr(self, "port", None),
            "type": getattr(self, "serviceType", None),
        }

    def _hydrate(self, d: dict):
        """
        @override
        """
        if "port" in d:
            self.port = d["port"]

        if "type" in d:
            self.serviceType = d["type"]
