# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from azdata.cli.core.models.dict_utils import SerializationUtils
from azdata.cli.core.models.kube_quantity import KubeQuantity
from typing import Union


class VolumeClaim(SerializationUtils):
    """
    A representation of a k8s VolumeClaim
    """
    def __init__(self, className: str = None, size: Union[str, KubeQuantity] = None):
        self.className = className
        self.size = size

    @property
    def className(self) -> str:
        return self._className

    @className.setter
    def className(self, n: str):
        self._className = n

    @property
    def size(self) -> KubeQuantity:
        return self._size

    @size.setter
    def size(self, s: Union[str, KubeQuantity]):
        if s is None:
            self._size = None
        else:
            self._size = KubeQuantity(s)

    def _to_dict(self):
        """
        @override
        """
        return {
            "size": self.size.quantity if self.size else None,
            "className": self.className,
        }

    def _hydrate(self, d: dict):
        """
        @override
        """
        if "className" in d:
            self.className = d["className"]

        if "size" in d:
            self.size = d["size"]
